@@ -8,6 +8,8 @@ use App::LDAP::LDIF::User;
 use Net::LDAP::Entry;
 use Term::ReadPassword;
 use Digest::MD5 qw(md5_base64);
+use Crypt::Password;
+use Crypt::Salt;
 
 sub run {
   my ($self,) = @_;
@@ -31,7 +33,8 @@ sub run {
   my $password = read_password("password: ");
   my $comfirm  = read_password("comfirm password: ");
   ($password eq $comfirm) or die "not the same";
-  $password = "{MD5}".md5_base64($password)."= =";
+  # $password = "{MD5}".md5_base64($password)."= =";
+  $password = '{crypt}'.password($password, salt().salt().salt().salt(), "sha512")->{crypted};
 
   my ($base, $scope) = split /\?/, $config->{nss_base_passwd};
   my $user = App::LDAP::LDIF::User->new(
