@@ -1,6 +1,9 @@
+use 5.010;
+use strict;
+use warnings;
+
 package App::LDAP::Command::Passwd;
 use base qw(App::CLI::Command);
-use 5.010;
 
 sub run {
   my ($self,) = @_;
